# ---------------------------------------------------------------------------
# mat2r.py
# Copyright (C) 2009 Minh Van Nguyen <nguyenminh2@gmail.com>
#
# Convert text representation of a Latora-Marchiori network to its R code
# representation. This Python script essentially generates R code to
# represent Latora-Marchiori networks stored in text files. Latora-Marchiori
# networks are (n, k) ring lattices, each with half the total number of its
# edges removed and the resulting network rewired as per Watts & Strogatz [2].
# Such networks are used in "Model 4" of Latora & Marchiori [1]. Before
# running this Python script, make sure that a directory named "networks-r"
# exists in the current directory.
#
# REFERENCES:
# [1] V. Latora & M. Marchiori. Economic small-world behavior in weighted
#     networks. The European Physical Journal B, 32(2):249--263, 2003.
#
# [2] D. Watts & S.H. Strogatz. Collective dynamics of "small-world"
#     networks. Nature, 393(4):440--442, 1998.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
# ---------------------------------------------------------------------------


nExperiments = 20
nProbs = 37
for e in xrange(1, nExperiments + 1):
    print "generate R code for networks in experiment %s" % e
    for p in xrange(1, nProbs + 1):
        inFile = open("networks-dat/graph-"
                      + str(e) + "-" + str(p) + ".dat", "r")
        outFile = open("networks-r/graph-"
                       + str(e) + "-" + str(p) + ".r", "w")
        nrow = int(inFile.readline().strip())
        ncol = int(inFile.readline().strip())
        rewireProb = float(inFile.readline().strip()) # don't write to file
        outFile.write("mat <- matrix(nrow = " + str(nrow)
                      + ", ncol = " + str(ncol) + ")\n")
        for i in xrange(1, nrow + 1):
            row = inFile.readline().strip()
            row = row.replace(" ", ", ")
            row = "c(" + row + ")"
            outFile.write("mat[" + str(i) + ",] <- " + row + "\n")
        inFile.close()
        outFile.close()
